@@ -2,13 +2,12 @@
 // Created by jorge on 12/16/20.
 //
 #include "include/Dataset.h"
-#include "MergerTask.h"
-#include "MergerTasksList.h"
+
 #include "SampleLocation.h"
 #include <boost/log/core.hpp>
 #include <boost/log/trivial.hpp>
 #include <boost/log/expressions.hpp>
-#include <boost/thread.hpp>
+
 
 namespace logging = boost::log;
 
@@ -16,8 +15,8 @@ size_t
 Dataset::LoadMetricsNamesFromChunk() {
     if (chunkVector.size() > 0) {
         if (lazyParsing && (chunkVector[0]->getUncompressedSize() == 0)) {
-            // miau the first chunk, so we have metric names.
-            chunkVector[0]->miau();
+            // Consume the first chunk, so we have metric names.
+            chunkVector[0]->Consume();
         }
         chunkVector[0]->getMetricNames(metricNames);
         return metricNames.size();
@@ -74,7 +73,7 @@ Dataset::IsMetricInDataset(const std::string& metric) {
     return false;
 }
 
-Dataset::MetricsPtr
+MetricsPtr
 Dataset::getMetric(std::string   metricName, const size_t start, const size_t end, bool ratedMetric)
 {
 
@@ -94,12 +93,11 @@ Dataset::getMetric(std::string   metricName, const size_t start, const size_t en
         // for chunks between start and end, start parser threads
         for (auto chunkNumber = start_chunk_pos.getChunkLoc(); chunkNumber<=end_chunk_pos.getChunkLoc(); ++chunkNumber ) {
             if (chunkVector[chunkNumber]->getUncompressedSize() == 0)
-                chunkVector[chunkNumber]->miau();
+                chunkVector[chunkNumber]->Consume();
         }
     }
 
-
-    Dataset::MetricsPtr metrics =  assembleMetricFromChunks(metricName, start_chunk_pos, end_chunk_pos);
+    MetricsPtr metrics =  assembleMetricFromChunks(metricName, start_chunk_pos, end_chunk_pos);
     if (ratedMetric)
         ConvertToRatedMetric(metrics);
 
@@ -107,18 +105,18 @@ Dataset::getMetric(std::string   metricName, const size_t start, const size_t en
 }
 
 SampleLocation
-Dataset::getLocationInMetric(size_t sample, bool fromStart) {
+Dataset::getLocationInMetric(unsigned long ts, bool fromStart) {
 
     auto chunkPos = Chunk::INVALID_CHUNK_NUMBER;
     auto samplePos = Chunk::INVALID_TIMESTAMP_POS;
 
     // Easy cases
-    if (sample == Dataset::INVALID_TIMESTAMP) {
-        if (fromStart) { // first sample of first chunk
+    if (ts == INVALID_TIMESTAMP) {
+        if (fromStart) { // first ts of first chunk
             chunkPos = 0;
             samplePos = 0;
         }
-        else { // last sample of last chunk
+        else { // last ts of last chunk
             chunkPos = chunkVector.size()-1;
             samplePos =  ChunkMetric::MAX_SAMPLES-1;
         }
@@ -129,12 +127,12 @@ Dataset::getLocationInMetric(size_t sample, bool fromStart) {
     //
     int chunkNumber = 0;
     for (auto c: chunkVector) {
-        if (sample >= c->getStart() && sample <= c->getEnd()) {  // this is the chunk
+        if (ts >= c->getStart() && ts <= c->getEnd()) {  // this is the chunk
             chunkPos = chunkNumber;
             // Timestamps 'start' metrics are always the 0-th position
-            auto ts = c->getMetric(0);
+            auto timestamps = c->getMetric(0);
             for (int i = 0; i < ChunkMetric::MAX_SAMPLES; ++i) {
-                if (ts->values[i] >= sample) {
+                if (timestamps->values[i] >= ts) {
                     samplePos = i;
 
                     if (i ==0 && !fromStart) {
@@ -149,11 +147,11 @@ Dataset::getLocationInMetric(size_t sample, bool fromStart) {
         }
         ++chunkNumber;
     }
-    SampleLocation pos(chunkPos,samplePos);
-    return pos;
+
+    return  SampleLocation (chunkPos,samplePos);
 }
 
-Dataset::MetricsPtr
+MetricsPtr
 Dataset::assembleMetricFromChunks(const std::string metricName, SampleLocation startLocation, SampleLocation endLocation) {
 
     // chunks and positions
@@ -163,7 +161,7 @@ Dataset::assembleMetricFromChunks(const std::string metricName, SampleLocation s
     auto endChunk = endLocation.getChunkLoc();
     auto endSamplePos = endLocation.getSampleLoc();
 
-    Dataset::MetricsPtr p = new std::vector<uint64_t>;
+    MetricsPtr p = new std::vector<uint64_t>;
     if (endChunk == startChunk) {
         auto sample_count = endSamplePos - startSamplePos;
         p->reserve(sample_count);
@@ -192,7 +190,7 @@ Dataset::assembleMetricFromChunks(const std::string metricName, SampleLocation s
 }
 
 bool
-Dataset::ConvertToRatedMetric(Dataset::MetricsPtr metric) {
+Dataset::ConvertToRatedMetric(MetricsPtr metric) {
 
     bool goesNegative = false;
 
@@ -233,12 +231,12 @@ Dataset::FileParsed(const std::string filePath, uint64_t start, uint64_t end, si
     filesParsed.emplace_back(fileData);
 }
 
-std::vector<Dataset::MetricsPtr>
+std::vector<MetricsPtr>
 Dataset::getMetrics(const std::vector<std::string> metricNames,
                     const size_t start, const size_t end,
                     const bool ratedMetrics) {
 
-    std::vector<Dataset::MetricsPtr> metricList;
+    std::vector<MetricsPtr> metricList;
 
     for(auto name : metricNames) {
         auto element = getMetric(name, start, end, ratedMetrics);
@@ -248,7 +246,7 @@ Dataset::getMetrics(const std::vector<std::string> metricNames,
     return metricList;
 }
 
-Dataset::MetricsPtr
+MetricsPtr
 Dataset::getMetricMatrix(const std::vector<std::string> metricNames, size_t *stride, const size_t start, const size_t end,
                          const bool ratedMetrics) {
 
@@ -267,7 +265,7 @@ Dataset::getMetricMatrix(const std::vector<std::string> metricNames, size_t *str
     }
 
     // Allocate
-    Dataset::MetricsPtr p = new std::vector<uint64_t>;
+    MetricsPtr p = new std::vector<uint64_t>;
 
     p->reserve(len*metricNames.size());
 
@@ -279,7 +277,6 @@ Dataset::getMetricMatrix(const std::vector<std::string> metricNames, size_t *str
     }
 
     return p;
-
 }
 
 uint64_t Dataset::getMetricValue(std::string metricName, size_t pos) {
@@ -289,3 +286,38 @@ uint64_t Dataset::getMetricValue(std::string metricName, size_t pos) {
 
     return v[posInChunk];
 }
+
+Timestamp
+Dataset::getStartTimestamp() {
+    return chunkVector[0]->getStart();
+}
+
+Timestamp
+Dataset::getEndTimestamp() {
+    return chunkVector[chunkVector.size()-1]->getEnd();
+}
+
+std::string
+Dataset::getJsonFromTimestamp(Timestamp ts) {
+    auto location = getLocationInMetric(ts, true);
+
+    if (location.getChunkLoc() == Chunk::INVALID_CHUNK_NUMBER
+    || location.getSampleLoc() == Chunk::INVALID_TIMESTAMP_POS)
+        return "{}";
+
+    return chunkVector[location.getChunkLoc()]->getJsonAtPosition(location.getSampleLoc());
+}
+
+
+std::string
+Dataset::getJsonAtPosition(int pos) {
+
+    int chunkNumber = pos / ChunkMetric::MAX_SAMPLES;
+    int posInChunk = pos % ChunkMetric::MAX_SAMPLES;
+    return chunkVector[chunkNumber]->getJsonAtPosition(posInChunk);
+}
+
+std::string
+Dataset::getCsvFromTimestamp(Timestamp ts) {
+    return nullptr;
+}
