@@ -6,26 +6,27 @@
 #include <sys/stat.h>
 #include <string>
 
+// From libbson
+#include <bson/bson.h>
+
+// Boost
 #include <boost/log/core.hpp>
 #include <boost/log/trivial.hpp>
 #include <boost/log/expressions.hpp>
-// From libbson
-#include <bson/bson.h>
+
 #include <boost/thread.hpp>
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/classification.hpp>
+#include <utility>
 
-#include <sys/time.h>
 #include <sys/resource.h>
 
-
-#include <boost/property_tree/ptree.hpp>
-#include <boost/property_tree/json_parser.hpp>
+#include "JSONWriter.h"
+#include "CSVWriter.h"
 
 
 namespace logging = boost::log;
 
-#define FALSE 0
 
 static double double_time_of_day() {
     struct timeval timeval{};
@@ -50,7 +51,7 @@ FTDCParser::parseInfoChunk(const bson_t *bson) {
  int
  ParserTaskConsumerThread(ParserTasksList *parserTasks, Dataset *dataSet) {
 
-    bool logChunkMetrics = FALSE;
+    bool logChunkMetrics = false;
     while (!parserTasks->empty()) {
 
         ParserTask  *task = parserTasks->pop();
@@ -58,14 +59,14 @@ FTDCParser::parseInfoChunk(const bson_t *bson) {
         auto chunk = new Chunk(task->getData(), task->getDataSize(), task->getId(), logChunkMetrics);
 
         // only once
-        logChunkMetrics = FALSE;
+        logChunkMetrics = false;
 
         if (dataSet->getLazyParsing()) {
             dataSet->addChunk(chunk);
         } else {
 
             // Decompress and check sizes
-            if (chunk->miau()) {
+            if (chunk->Consume()) {
                 dataSet->addChunk(chunk);
             } else {
                 delete chunk;
@@ -82,6 +83,9 @@ FTDCParser::parseInfoChunk(const bson_t *bson) {
 }
 
 
+
+
+
 bson_reader_t *
 FTDCParser::open(std::string file_path) {
 
@@ -114,14 +118,15 @@ FTDCParser::parseFiles(std::string file_paths, const bool onlyMetadata, const bo
 }
 
 int
-FTDCParser::parseFiles(std::vector<std::string> const *filePaths, const bool onlyMetadata, const bool onlyMetricNames, const bool lazyParsing) {
+FTDCParser::parseFiles(std::vector<std::string> const *filePaths,
+                       const bool onlyMetadata, const bool onlyMetricNames, const bool lazyParsing) {
     bson_reader_t *reader;
     const bson_t *pBsonChunk;
 
     double date_time_before, date_time_after, date_time_delta;
 
     namespace logging = boost::log;
-    logging::core::get()->set_filter(logging::trivial::severity >  logging::trivial::info);
+    logging::core::get()->set_filter(logging::trivial::severity >  logging::trivial::debug);
 
     for (auto fileName : *filePaths) {
         BOOST_LOG_TRIVIAL(info) << "File: " << fileName;
@@ -134,8 +139,8 @@ FTDCParser::parseFiles(std::vector<std::string> const *filePaths, const bool onl
         bool at_EOF = false;
         unsigned int chunkCount = 0;
         bool parsing_values = false;
-        uint64_t first_id = Dataset::INVALID_TIMESTAMP;
-        uint64_t current_id = Dataset::INVALID_TIMESTAMP;
+        uint64_t first_id = INVALID_TIMESTAMP;
+        uint64_t current_id = INVALID_TIMESTAMP;
 
         while ((pBsonChunk = bson_reader_read(reader, &at_EOF))) {
 
@@ -146,9 +151,6 @@ FTDCParser::parseFiles(std::vector<std::string> const *filePaths, const bool onl
                 if (onlyMetadata) break;
             }
             else {
-
-
-
                 bson_iter_t iter;
 
                 if (bson_iter_init(&iter, pBsonChunk)) {
@@ -168,7 +170,7 @@ FTDCParser::parseFiles(std::vector<std::string> const *filePaths, const bool onl
                         } else if (BSON_ITER_HOLDS_DATE_TIME(&iter)) {
 
                             current_id = bson_iter_date_time(&iter);
-                            if (first_id == Dataset::INVALID_TIMESTAMP) first_id = current_id;
+                            if (first_id == INVALID_TIMESTAMP) first_id = current_id;
                         } else if (BSON_ITER_HOLDS_INT32(&iter)) {
                             ; // type = bson_iter_int32(&iter);
                         }
@@ -207,7 +209,7 @@ FTDCParser::parseFiles(std::vector<std::string> const *filePaths, const bool onl
                  << dataSet.getMetricNamesCount() << " metrics with "
                  << dataSet.getMetricLength() << " samples";
 
-        struct rusage usage;
+        struct rusage usage{0};
         getrusage(RUSAGE_SELF, &usage);
 
         BOOST_LOG_TRIVIAL(info) << "maximum resident set size: " << usage.ru_maxrss
@@ -252,69 +254,64 @@ FTDCParser::getMetricsNames() {
     return metricNames;
 }
 
-Dataset::MetricsPtr
-FTDCParser::getMetric(const std::string name, const size_t start, const size_t end, const bool ratedMetric) {
+MetricsPtr
+FTDCParser::getMetric(const std::string name, const Timestamp start, const Timestamp end, const bool ratedMetric) {
      return dataSet.getMetric(name, start, end, ratedMetric);
 }
 
-std::vector<Dataset::MetricsPtr>
-FTDCParser::getMetric(const std::vector<std::string> metricNames, const size_t start, const size_t end, const bool ratedMetric) {
+std::vector<MetricsPtr>
+FTDCParser::getMetric(const std::vector<std::string> metricNames, const Timestamp start, const Timestamp end, const bool ratedMetric) {
     return  dataSet.getMetrics(metricNames, start, end, ratedMetric);
 }
 
-Dataset::MetricsPtr
-FTDCParser::getMetricMatrix(const std::vector<std::string> metricNames,   size_t *stride,  const size_t start, const size_t end, const bool ratedMetric) {
+MetricsPtr
+FTDCParser::getMetricMatrix(const std::vector<std::string> metricNames,   size_t *stride,  const Timestamp start, const Timestamp end, const bool ratedMetric) {
     return  dataSet.getMetricMatrix(metricNames, stride, start, end, ratedMetric);
 }
 
-boost::property_tree::ptree pt;
 
+// - - - - - - - - - - - - - - - - - - -
 std::string
-FTDCParser::getMetricAsJSONDoc(std::vector<std::string> *metricNames, size_t pos) {
-
-
-    for (auto metricName: *metricNames) {
-        // for debugging purposes, stop at this metric name
-        //if (metricName == "serverStatus.encryptionAtRest.encryptionEnabled") break;
-
-
-        pt.put(metricName, dataSet.getMetricValue(metricName, pos));
-
-    }
-
-    std::stringstream ss;
-    boost::property_tree::json_parser::write_json(ss, pt, false);
-
-    return ss.str();
+FTDCParser::getJsonAtPosition(size_t position) {
+    return dataSet.getJsonAtPosition(position);
 }
 
 
 size_t
-FTDCParser::dumpDocsAsJson(const std::string inputFile, const std::string outputFile) {
+FTDCParser::dumpDocsAsJsonTimestamps(const std::string  inputFile, const std::string  outputFile,
+                                     const Timestamp start, const Timestamp end) {
 
-    if (!parseFiles(inputFile,FALSE,FALSE,FALSE)) {
+    if (!parseFiles(inputFile, false, false, false)) {
 
+        //TODO: these could come from dataset.
+        // Get metric names
         std::vector<std::string> metricNames;
         metricNames = getMetricsNames();
-        std::ofstream outdata;
 
-        outdata.open(outputFile); // opens the file
-        if( !outdata ) { // file couldn't be opened
-
-            return 0;
-        }
-
-        for(size_t i; i<dataSet.getMetricLength(); ++i) {
-            std::string str = getMetricAsJSONDoc(&metricNames, i);
-            BOOST_LOG_TRIVIAL(info) << str;
-            outdata << str;
-            BOOST_LOG_TRIVIAL(info) << i;
-        }
-        outdata.close();
-
-        return dataSet.getMetricLength();
+        JSONWriter w;
+        return  w.dumpTimestamps( &dataSet, outputFile, start, end, false);
     }
+    else
+        return 0;
+}
 
-    return 0;
+
+size_t
+FTDCParser::dumpDocsAsCsvTimestamps(std::string inputFile, std::string outputFile, Timestamp start, Timestamp end) {
+
+    if (!parseFiles(std::move(inputFile), false, false, false)) {
+
+        //TODO: these could come from dataset.
+        // Get metric names
+        std::vector<std::string> metricNames;
+        metricNames = getMetricsNames();
+
+        CSVWriter c;
+
+        c.dumpCSVTimestamps(&dataSet, outputFile, start, end, false);
+        return 1;
+    }
+    else
+        return 0;
 }
 
