@@ -152,8 +152,9 @@ def pyftdc_pull_numpy_vectors(filepath, ftdc_metrics_keys, padZeros=False, t0=-1
 
 def test_stall():
 
-    #file = '/home/jorge/CLionProjects/mongo_ftdc/tests/diagnostic.data_40/metrics.2021-07-22T17-16-31Z-00000'
-    file = '/Users/jorge.imperial/CLionProjects/mongo_ftdc/tests/diagnostic.data_40/metrics.2021-07-22T17-16-31Z-00000'
+    file = '/home/jorge/CLionProjects/mongo_ftdc/tests/diagnostic.data_40/metrics.2021-07-22T17-16-31Z-00000'
     v = pyftdc_pull_numpy_vectors(file, ftdc_metrics_keys)
 
-    print("done")
\ No newline at end of file
+    print("done")
+
+
